import { ICommandMapper, ICommandUnmapper } from "@robotlegsjs/core";
export declare const ISignalCommandMap: unique symbol;
/**
 * The Signal Command Map allows you to bind Phaser.Signal to Commands
 */
export interface ISignalCommandMap {
    /**
     * Creates a mapping for a Phaser.Signals based trigger
     *
     * @param signalClass The concrete Phaser.Signals class
     * @return Command mapper
     */
    map(signalClass: Object): ICommandMapper;
    /**
     * Unmaps a Phaser.Signal based trigger from a command
     *
     * @param signalClass The concrete Phaser.Signal class
     * @return Command unmapper
     */
    unmap(signalClass: Object): ICommandUnmapper;
    /**
     * Adds a handler to process mappings
     *
     * @param handler Function that accepts a mapping
     * @return Self
     */
    addMappingProcessor(handler: Function): ISignalCommandMap;
}
